@@ -158,11 +158,11 @@ def node_list_conversion(df_graph):
     for i in range(len(node_list)):
         my_dictionary[str(node_list["screen_name"][i])] = node_list["id"][i]
     my_dictionary["Empty"] = len(node_list)
-    df_graph["screen_name_mention_str"] = df_graph["screen_name_mention"]
-    df_graph["screen_name_str"] = df_graph["screen_name"]
+    df_graph["screen_name_mention_num"] = df_graph["screen_name_mention"]
+    df_graph["screen_name_num"] = df_graph["screen_name"]
     for index, row in df_graph.iterrows():
-        df_graph.loc[index, 'screen_name'] = my_dictionary[row["screen_name"]]
-        df_graph.loc[index, 'screen_name_mention'] = my_dictionary[row["screen_name_mention"]]
+        df_graph.loc[index, 'screen_name_num'] = my_dictionary[row["screen_name"]]
+        df_graph.loc[index, 'screen_name_num'] = my_dictionary[row["screen_name_mention"]]
     
     return df_graph, node_list
     
@@ -176,7 +176,7 @@ def buildingGraph(df_graph):
 
 
 def girvanNewman_alg(node_list,df_graph):
-    DiG = building_DiGraph(node_list,df_graph)
+    DiG = building_DiGraph(node_list,df_graph,alg="str")
     communities_generator = community.girvan_newman(DiG)
     top_level_communities = next(communities_generator)
     next_level_communities = next(communities_generator)
@@ -203,7 +203,7 @@ def louvain_alg(node_list,df_graph):
 
 def leiden_alg (df_graph):
     df_graph, node_list = node_list_conversion(df_graph)
-    DiG = building_DiGraph(list(node_list["id"]),df_graph)
+    DiG = building_DiGraph(list(node_list["id"]),df_graph,alg="num")
     coms = algorithms.leiden(DiG)
     data = pd.DataFrame()
     data["id"]=  coms.communities
@@ -221,7 +221,7 @@ def infMap_alg(df_graph):
     im = Infomap("--two-level --directed")
     df_graph, node_list = structure_leiden(df_graph)
     for i in range(len(df_graph)):
-        im.add_link(df_graph['screen_name'].iloc[i],df_graph['screen_name_mention'].iloc[i])
+        im.add_link(df_graph['screen_name_num'].iloc[i],df_graph['screen_name_mention_num'].iloc[i])
     # Run the Infomap search algorithm to find optimal modules
     im.run()
     
@@ -246,11 +246,11 @@ def graph_algoritm_selected(df_graph,selection,node_list):
     print(type(selection))
     print(selection)
     if(selection =="1"):
-        df_algComu = girvanNewman_alg(node_list,df_graph)
+        df_algComu = girvanNewman_alg(node_list,df_graph,alg="str")
     elif(selection =="2"):
-        df_algComu = leiden_alg(df_graph)
+        df_algComu = leiden_alg(df_graph,alg="num")
     elif(selection =="3"):
-        df_algComu = infMap_alg(df_graph)
+        df_algComu = infMap_alg(df_graph, alg="num")
     else:#default
         if(len_nodeList < 1000):
             df_algComu = girvanNewman_alg(node_list,df_graph)
@@ -263,13 +263,17 @@ def graph_algoritm_selected(df_graph,selection,node_list):
 
 
 #------------------------------Directed Graph ---------------------------------------------------
-def building_DiGraph(node_list, df):
+def building_DiGraph(node_list, df_graph, alg_type):
     DiG = nx.DiGraph()
     DiG.add_nodes_from(node_list)
-    for i in range(len(df)):
-        #Second condition for delete empty when we convert screen_name to numbers for specific algorithms
-        if((df['screen_name_mention'].iloc[i] !="Empty") | (df["screen_name_mention"].iloc[i] != len(node_list))):
-            DiG.add_edge(df['screen_name'].iloc[i],df['screen_name_mention'].iloc[i])
+    for i in range(len(df_graph)):
+        if alg_type=="str":            
+            if(df['screen_name_mention'].iloc[i] !="Empty"):
+                DiG.add_edge(df['screen_name'].iloc[i],df['screen_name_mention'].iloc[i])
+        else:
+            #Second condition for delete empty when we convert screen_name to numbers for specific algorithms
+            if(df["screen_name_mention"].iloc[i] != len(node_list)):
+                DiG.add_edge(df['screen_name_num'].iloc[i],df['screen_name_mention_num'].iloc[i])
     return DiG
     
 
@@ -390,12 +394,11 @@ def graph_json_values(df_graph, df_algComu):
       
     data['edges'] = []
     for i in range(len(df_graph)):
-      
-      data['edges'].append({
-          'screen_name': df_graph["screen_name"].iloc[i],
+        data['edges'].append({
+          'screen_name': df_graph[col].iloc[i],
           'screen_name_mention': df_graph["screen_name_mention"].iloc[i],
           'iteration': str(df_graph["iteration"].iloc[i])
-      })
+        })
       
     return json.dumps(data)
     
